@@ -2,8 +2,9 @@
 
 export TESTSJS_SPARKJOB_SERVER_URL=${TESTSJS_SPARKJOB_SERVER_URL:-http://localhost:8090}
 export TESTSJS_SPARK_TEST_CTX=${TESTSJS_SPARK_TEST_CTX:-python-sjsclient-ft}
-export TESTSJS_SPARKJOB_JAR_URL=${TESTSJS_SPARKJOB_JAR_URL:-http://localhost/job-server-tests_2.10-0.6.1-SNAPSHOT.jar}
-export TESTSJS_SPARKJOB_JARS_DIR=/tmp/testsjs_sparkjob_jars
+export TESTSJS_SPARKJOB_JAR_URL=${TESTSJS_SPARKJOB_JAR_URL:-file://$(find `pwd` -name job-server-tests*.jar)}
+export TESTSJS_SPARKJOB_EGG_URL=${TESTSJS_SPARKJOB_EGG_URL:-file://$(find `pwd` -name sjs_python_example*egg)}
+export TESTSJS_SPARKJOB_ARTIFACT_DIR=/tmp/testsjs_sparkjob_jars
 export TESTSJS_SPARKJOB_SERVER_AUTH_ENABLED=${TESTSJS_SPARKJOB_SERVER_AUTH_ENABLED:-1}
 if [ $TESTSJS_SPARKJOB_SERVER_AUTH_ENABLED -eq 1 ]; then
    export TESTSJS_SPARKJOB_SERVER_USERNAME=sjs
@@ -16,8 +17,14 @@ fi
 echo "Running functonal tests against spark job server, $TESTSJS_SPARKJOB_SERVER_URL"
 
 # Download the spark job jars archive.
-if ! curl -s -o $TESTSJS_SPARKJOB_JARS_DIR/$(basename $TESTSJS_SPARKJOB_JAR_URL) --create-dirs $TESTSJS_SPARKJOB_JAR_URL; then
-    echo "Failed to connect to Spark job Jars archive server $TESTSJS_SPARKJOB_JAR_URL"
+if ! curl -s -o $TESTSJS_SPARKJOB_ARTIFACT_DIR/$(basename $TESTSJS_SPARKJOB_JAR_URL) --create-dirs $TESTSJS_SPARKJOB_JAR_URL; then
+    echo "Failed to download apark job jar archive from $TESTSJS_SPARKJOB_JAR_URL"
+    exit 1
+fi
+
+# Download the spark job egg archive.
+if ! curl -s -o $TESTSJS_SPARKJOB_ARTIFACT_DIR/$(basename $TESTSJS_SPARKJOB_EGG_URL) --create-dirs $TESTSJS_SPARKJOB_EGG_URL; then
+    echo "Failed to download apark job egg archive from $TESTSJS_SPARKJOB_EGG_URL"
     exit 1
 fi
 
